unit uPlannerRole;

interface

uses
  System.SysUtils, System.Generics.Collections,
  Vcl.Dialogs, Vcl.Forms,
  Data.DB,
  AdvOfficePager, AdvPanel,
  DBPlanner, Planner, DBPlannerMonthView, PlanDraw;

type
  TRolePlanner = class(TObject)
  strict private
  const
    SideBar45 = 45;
    SideBar65 = 65;
  var
    FDataSet: TDataSet;
    FForm: TForm;
    FPager: TAdvOfficePager;
    FPlannerDay: TDBPlanner;
    FPlannerMonth: TDBPlannerMonthView;
    FPlannerWeek: TDBPlanner;
    FPropertiePanel: array[0..7] of TAdvPanel;
    FShapeDrawTool: TObjectList<TShapeDrawTool>;
    procedure FillPropertiePanel;
    procedure GetShapeDrawTool;
  public
    constructor CreateForm(const AForm: TForm; const ADataSource: TDataSource);
    destructor Destroy; override;
    procedure SetPlannerProperies;
    property ShapeDrawTool: TObjectList<TShapeDrawTool> read FShapeDrawTool;
  end;

implementation

{ TRolePlanner }

uses
   PlannerRole;

constructor TRolePlanner.CreateForm(const AForm: TForm; const ADataSource: TDataSource);
var
  Form: TfrmPlannerRole;
begin
  FForm := AForm;
  Form := TfrmPlannerRole(FForm);
  FPager := Form.offpgrPlanner;
  FPlannerDay := Form.dbplDay;
  FPlannerWeek := Form.dbplWeek;
  FPlannerMonth := Form.dbpmwMonth;
  FillPropertiePanel;
  FDataSet := ADataSource.DataSet;
  GetShapeDrawTool;
end;

destructor TRolePlanner.Destroy;
begin
  FreeAndNil(FShapeDrawTool);
  inherited;
end;

procedure TRolePlanner.FillPropertiePanel;
var
  Form: TfrmPlannerRole;
begin
  Form := TfrmPlannerRole(FForm);
  FPropertiePanel[Ord(TViews(vwMultiDay))] := Form.jstpnlMultiDay;
  FPropertiePanel[Ord(TViews(vwPeriod))] := Form.jstpnlPeriod;
  FPropertiePanel[Ord(TViews(vwHalfDayPeriod))] := Form.jstpnlHalfDayPeriod;
  FPropertiePanel[Ord(TViews(vwMonth))] := Form.jstpnlMonth;
  FPropertiePanel[Ord(TViews(vwMultiMonth))] := Form.jstpnlMultiMonth;
  FPropertiePanel[Ord(TViews(vwTimeLine))] := Form.jstpnlTimeLine;
  FPropertiePanel[Ord(TViews(vwActiveDay))] := Form.jstpnlActiveDay;
  FPropertiePanel[Ord(TViews(vwActiveDayPeriod))] := Form.jstpnlActiveDayPeriod;
end;

procedure TRolePlanner.GetShapeDrawTool;
begin
  FShapeDrawTool := TObjectList<TShapeDrawTool>.Create(True);
  FShapeDrawTool.Add(TShapeDrawTool.Create(nil));
  FShapeDrawTool.Last.Shape := ssCircle;
  FShapeDrawTool.Add(TShapeDrawTool.Create(nil));
  FShapeDrawTool.Last.Shape := ssTriangle;
  FShapeDrawTool.Add(TShapeDrawTool.Create(nil));
  FShapeDrawTool.Last.Shape := ssHArrow;
  FShapeDrawTool.Add(TShapeDrawTool.Create(nil));
  FShapeDrawTool.Last.Shape := ssVArrow;
  FShapeDrawTool.Add(TShapeDrawTool.Create(nil));
  FShapeDrawTool.Last.Shape := ssTriangles;
  FShapeDrawTool.Add(TShapeDrawTool.Create(nil));
  FShapeDrawTool.Last.Shape := ssCircles;
  FShapeDrawTool.Add(TShapeDrawTool.Create(nil));
  FShapeDrawTool.Last.Shape := ssSquares;
end;

procedure TRolePlanner.SetPlannerProperies;
begin
  TDBItemSource(FPlannerDay.ItemSource).DataSource.DataSet.Refresh;
  FPlannerDay.ItemSource.Active := False;
  FPlannerDay.ItemSource.Active := True;  // FI:W508
end;

end.
